@@ -2,12 +2,41 @@ import pytest
 
 
 class Component:
-    def __init__(self, endpoints, references=None):
+    """CRUDL component that can (at least) be created and deleted.
+
+    A Component is specified mainly by an Endpoints object. This
+    must contain the different endpoints for, e.g., creating and
+    deleting an entry but none are enforced.
+    
+    Furthermore, it holds a list of referenced components, e.g.,
+    components that must exist and are referenced by an id.
+    An example would be a user Component which references a department
+    Component which references a company component. When creating
+    a user, we must specify the referenced department, e.g., via a
+    department_id, which identifies an existing department.
+
+    Example:
+        company = Component("Company", company_endpoints)
+        user = Component("User", user_endpoints, [company])
+    
+    Args:
+        name (:obj:`str`):
+            Name of the component.
+        endpoints (:obj:`Endpoints`):
+            Endpoints for this component.
+        references (:obj:`list` of :obj:`str`):
+            List of referenced components.
+    """
+    def __init__(self, name, endpoints, references=None):
         if not all([hasattr(endpoints, k) for k in ["create", "delete"]]):
             raise ValueError("Component must have create and delete endpoints. "
                              + "Only has: {}".format(list(endpoints.__dict__.keys())))
+        self.name = name
         self.endpoints = endpoints
         self.references = references if references else {}
+    
+    def __str__(self):
+        return "'{}' component".format(self.name)
 
     def valids(self,
                endpoint=None,
@@ -50,6 +79,10 @@ class Component:
         invalids = []
         refs = {}
         for invalid in endpoint.dummy.invalids(count=count, exhaustive=exhaustive, **kwargs):
+            if isinstance(invalid, tuple):
+                invalid, reason = invalid
+            else:
+                reason = None
             invalid = {**invalid, **values}
             if add_references:
                 for k, ref_comp in self.references.items():
@@ -58,7 +91,10 @@ class Component:
                             spec = ref_comp.valids()[0]
                             refs[k] = ref_comp.endpoints.create.call(spec)
                         invalid[k] = refs[k]["id"]
-            invalids.append(invalid)
+            if reason is None:
+                invalids.append(invalid)
+            else:
+                invalids.append((invalid, reason))
         return invalids
 
     def create(self, spec=None, **kwargs):
